# -*- coding: utf-8 -*-
"""
collectr
--------

collectr is static file management for S3, for human beings. See README.md for
more.

:copyright: (c) 2013 Cory Benfield
:license: MIT, see LICENSE for details.
"""

__title__ = 'collectr'
__version__ = '0.0.4'
__build__ = 0x000001
__author__ = 'Cory Benfield'
__license__ = 'MIT'
__copyright__ = 'Copyright 2013 Cory Benfield'

from .api import *
from . import exceptions
